@@ -140,7 +140,7 @@ def get_schema(dag_name):
 
 def cf_solve_app(app, secrets, **kwargs):
     if kwargs["dag_run"].conf.get("checks_only"):
-        return cf_check(app.check, secrets, **kwargs)
+        return cf_check(app.check, app.name, secrets, **kwargs)
     else:
         return cf_solve(app.solve, app.name, secrets, **kwargs)
 
@@ -160,9 +160,13 @@ def cf_solve(fun, dag_name, secrets, **kwargs):
         execution_data = client.get_data(exec_id)
         execution_status = client.update_status(exec_id, {"status": 0})
         data = execution_data["data"]
+        solution_data = execution_data["solution_data"]
         config = execution_data["config"]
         inst_id = execution_data["id"]
-        solution, sol_checks, inst_checks, log, log_json = fun(data, config)
+
+        solution, sol_checks, inst_checks, log, log_json = fun(
+            data, config, solution_data
+        )
 
         # We connect again to cornflow in case that more than 24 hours
         # have passed from the first time we connect
@@ -213,7 +217,7 @@ def cf_solve(fun, dag_name, secrets, **kwargs):
         raise AirflowDagException("There was an error during the solving")
 
 
-def cf_check(fun, secrets, **kwargs):
+def cf_check(fun, dag_name, secrets, **kwargs):
     """
     Connect to cornflow, ask for data, check the solution data and write the checks in cornflow
     :param fun: The function to use to check the data
@@ -221,46 +225,61 @@ def cf_check(fun, secrets, **kwargs):
     :param kwargs: other kwargs passed to the dag task.
     :return:
     """
-    client = connect_to_cornflow(secrets)
-    exec_id = kwargs["dag_run"].conf["exec_id"]
-    current_exec_data = client.get_data(exec_id)
-    config = current_exec_data["config"]
-    exec_to_check_id = config["execution_id"]
-    instance_to_check_data = client.get_data(exec_to_check_id)
-    exec_to_check_data = client.get_solution(exec_to_check_id)
-    instance_data = instance_to_check_data["data"]
-    inst_id = instance_to_check_data["id"]
-    solution_data = exec_to_check_data["data"]
     try:
+        client = connect_to_cornflow(secrets)
+        exec_id = kwargs["dag_run"].conf["exec_id"]
+        execution_data = client.get_data(exec_id)
+        config = execution_data["config"]
+
+        instance_data = execution_data["data"]
+        inst_id = execution_data["id"]
+        solution_data = execution_data["solution_data"]
+
         inst_checks, sol_checks, log_json = fun(instance_data, solution_data)
+
+        if config.get("checks_only"):
+            payload = dict(
+                state=1,
+                log_json=log_json,
+                log_text="Data checked.",
+                solution_schema=dag_name,
+                inst_checks=inst_checks,
+                inst_id=inst_id,
+            )
+        else:
+            payload = dict(
+                inst_checks=inst_checks,
+                inst_id=inst_id,
+                state=1,
+            )
+
+        if sol_checks is not None:
+            payload["checks"] = sol_checks
+
+        try_to_write_solution(client, exec_id, payload)
+
+        case_id = kwargs["dag_run"].conf.get("case_id")
+        if case_id is not None:
+            checks_payload = dict(checks=payload["inst_checks"])
+            if sol_checks is not None:
+                checks_payload["solution_checks"] = sol_checks
+            try:
+                client.write_case_checks(case_id=case_id, **checks_payload)
+            except CornFlowApiError:
+                try_to_save_error(client, exec_id, -6)
+                raise AirflowDagException("The writing of the case checks failed")
+
+        # # The validation went correctly: can save the solution without problem
+        return "Checks saved"
+
     except Exception as e:
         if config.get("msg", True):
             print("Some unknown error happened")
         try_to_save_error(client, exec_id, -1)
+        client.update_status(exec_id, {"status": -1})
         raise AirflowDagException(
             "There was an error during the verification of the data"
         )
-    payload = dict(
-        state=1,
-        log_json=log_json,
-        log_text="Instance and solution checked.",
-        solution_schema="_data_checks",
-        checks=sol_checks,
-        inst_checks=inst_checks,
-        inst_id=inst_id,
-        data=dict(solution_checks=sol_checks, instance_checks=inst_checks),
-    )
-
-    try_to_write_solution(client, exec_id, payload)
-    try:
-        client.write_solution(execution_id=exec_to_check_id, checks=sol_checks)
-    except CornFlowApiError:
-        try_to_save_error(client, exec_id, -6)
-        # attempt to update the execution with a failed status.
-        raise AirflowDagException("The writing of the solution failed")
-
-    # The validation went correctly: can save the solution without problem
-    return "Checks saved"
 
 
 class NoSolverException(Exception):
